==> openGion7.0.5.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE72S.sql <==
/****************************************************************************/
/* GE72 ( ﾌｧｲﾙﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE72 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*   1 ｼｽﾃﾑID       */
 , EXECID           VARCHAR2 (   20 )                   NOT NULL            /*   2 処理ID       */
 , NAME_JA          VARCHAR2 (  200 )                                       /*   3 名称         */
 , SEQNO            NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*   4 表示順       */
 , RUNTYPE          VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /*   5 実行方法     */
 , RUNPG            VARCHAR2 (  200 )                                       /*   6 実行ﾌﾟﾛｸﾞﾗﾑ  */
 , CLMS             VARCHAR2 ( 1000 )                                       /*   7 外部ｶﾗﾑ指定  */
 , PARAMS           VARCHAR2 ( 4000 )                                       /*   8 ﾊﾟﾗﾒｰﾀ       */
 , DBID             VARCHAR2 (   20 )                                       /*   9 ﾃﾞｰﾀﾍﾞｰｽID   */
 , TABLE_NAME       VARCHAR2 (   50 )                                       /*  10 ﾃｰﾌﾞﾙ名      */
 , SHT_NOS          VARCHAR2 (   50 )                                       /*  11 ｼｰﾄ番号      */
 , FILE_ENC         VARCHAR2 (   20 )                                       /*  12 ｴﾝｺｰﾄﾞ       */
 , SKIP_CNT         NUMBER   (    3 )                   NOT NULL            /*  13 先頭ｽｷｯﾌﾟ数  */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /*  14 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR2 (   20 )                                       /*  15 設変番号     */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成者       */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE72S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE72T00 
  BEFORE INSERT ON GE72
  FOR EACH ROW 
  BEGIN 
    SELECT GE72S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE72S.sql <==
/****************************************************************************/
/* GE72 ( ﾌｧｲﾙﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2020/12/16 08:13:51                                            */
/****************************************************************************/

CREATE TABLE GE72 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*   1 ｼｽﾃﾑID       */
 , EXECID           VARCHAR2 (   20 )                   NOT NULL            /*   2 処理ID       */
 , NAME_JA          VARCHAR2 (  200 )                                       /*   3 名称         */
 , SEQNO            NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*   4 表示順       */
 , RUNTYPE          VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /*   5 実行方法     */
 , RUNPG            VARCHAR2 (  200 )                                       /*   6 実行ﾌﾟﾛｸﾞﾗﾑ  */
 , CLMS             VARCHAR2 ( 1000 )                                       /*   7 外部ｶﾗﾑ指定  */
 , PARAMS           VARCHAR2 ( 4000 )                                       /*   8 ﾊﾟﾗﾒｰﾀ       */
 , DBID             VARCHAR2 (   20 )                                       /*   9 ﾃﾞｰﾀﾍﾞｰｽID   */
 , TABLE_NAME       VARCHAR2 (   50 )                                       /*  10 ﾃｰﾌﾞﾙ名      */
 , SHT_NOS          VARCHAR2 (   50 )                                       /*  11 ｼｰﾄ番号      */
 , FILE_ENC         VARCHAR2 (   20 )                                       /*  12 ｴﾝｺｰﾄﾞ       */
 , SKIP_CNT         NUMBER   (    3 )                   NOT NULL            /*  13 先頭ｽｷｯﾌﾟ数  */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /*  14 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR2 (   20 )                                       /*  15 設変番号     */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 作成日時     */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成者       */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE72S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE72T00 
  BEFORE INSERT ON GE72
  FOR EACH ROW 
  BEGIN 
    SELECT GE72S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
